@@ -1,5 +1,26 @@
 #!@PYTHON@
 
+#
+# this file is part of mftrace - a tool to generate scalable fonts from MF sources  
+#
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2
+# as published by the Free Software Foundation
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Library General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA 
+
+# Copyright (c)  2001--2006 by
+#  Han-Wen Nienhuys, Jan Nieuwenhuizen
+
 import string
 import os
 import optparse
@@ -982,6 +1003,7 @@ Copyright (c) 2005--2006 by
                   metavar='FILE',
                   action='store',
                   dest='tfm_file')
+    
     p.add_option ('-e', '--encoding',
                   metavar="FILE",
                   action='store',
@@ -1298,9 +1320,6 @@ def do_file (filename):
     progress (_ ("Font `%s'..." % basename))
     progress ('\n')
 
-    if not options.tfm_file:
-        options.tfm_file = find_file (basename + '.tfm')
-
     if not options.tfm_file:
         options.tfm_file = popen ("mktextfm %s 2>/dev/null" % shell_escape_filename (basename)).read ()
         if options.tfm_file:
@@ -1339,7 +1358,7 @@ def do_file (filename):
     temp_dir = setup_temp ()
 
     if options.verbose:
-        progress ('Temporary directory is `%s\' ' % temp_dir)
+        progress ('Temporary directory is `%s\'\n' % temp_dir)
 
     os.chdir (temp_dir)
 
